"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.executeSonarAnalysis = executeSonarAnalysis;
exports.filterSpecAndFeatureFiles = filterSpecAndFeatureFiles;
var _child_process = require("child_process");
var _sonarReportSummary = require("./sonarReportSummary");
var _logger = require("../../utils/logger");
var _popUpCli = require("../popUpCli");
var _getSonarProperties = require("./getSonarProperties");
// Js script to start sonar Server

/**
 *  cli cmd :
 *  npx ZDTestingFramework lint -- --executeFrom=ci --diffPath="" --repo="deskClientApp" --branch="" --username=""
 */

function executeSonarAnalysis(cliParams) {
  _logger.Logger.createLogFile();
  var cliObjects = cliParams;
  var _cliObjects$executeFr = cliObjects.executeFrom,
    executeFrom = _cliObjects$executeFr === void 0 ? "ci" : _cliObjects$executeFr;
  var command = (0, _getSonarProperties.getSonarProperties)(cliObjects);
  var child_process = (0, _child_process.spawn)("java", command);
  _logger.Logger.start('sending report to sonarQube ...');
  child_process.stdout.on("data", function (data) {
    _logger.Logger.note(data);
  });
  child_process.stderr.on("data", function (errorOut) {
    // error will appear here
    // Logger.error(Logger.FAILURE_TYPE, errorOut);
  });
  child_process.on("error", function (error) {
    _logger.Logger.cliLog(_logger.Logger.SUCCESS_TYPE, 'failed to send report to sonarQube ...');
    _logger.Logger.error(_logger.Logger.FAILURE_TYPE, "Error: ".concat(error.message));
  });
  child_process.on("close", function (code) {
    _logger.Logger.stop();
    (0, _sonarReportSummary.writeSummaryOfLint)(cliParams);
    _logger.Logger.cliLog(_logger.Logger.SUCCESS_TYPE, 'SonarQube analysis completed...');
    _logger.Logger.cliLog(_logger.Logger.SUCCESS_TYPE, "Report successfully sent to the server :  Status - ".concat(code === 0 ? "Success" : "Failure"));
    _logger.Logger.cliLog(_logger.Logger.PATH_TYPE, "Report URL - ".concat((0, _sonarReportSummary.getSummaryOfLint)(cliParams).reportUrl));
    // Logger.log(Logger.INFO_TYPE,`Entire File Report - ${getSummaryOfLint(cliParams).allIssueInFile}`  );
    if (executeFrom == "pre-commit") {
      _logger.Logger.log(_logger.Logger.SUCCESS_TYPE, "lint triggered from pre-commit ...");
      if (!(0, _sonarReportSummary.getLintStatus)(cliObjects).status && (0, _sonarReportSummary.getLintStatus)(cliObjects).message == "failed") {
        _logger.Logger.log(_logger.Logger.FAILURE_TYPE, "rules violated .. ");
        (0, _popUpCli.showMsgPopUp)("IssueFound");
        process.exit(1);
      } else {
        (0, _popUpCli.showMsgPopUp)("NoIssueFound");
      }
    }
  });
}
function filterSpecAndFeatureFiles(resultJson) {
  return resultJson.reduce(function (filesPath, fileReport) {
    if (fileReport.includes(".feature")) {
      filesPath.featureFilesPath.push(fileReport);
    } else {
      filesPath.jsFilePath.push(fileReport);
    }
    return filesPath;
  }, {
    jsFilePath: [],
    featureFilesPath: []
  });
}