"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.checkIfFileExists = checkIfFileExists;
exports.deleteFile = deleteFile;
exports.deleteFolder = deleteFolder;
exports.getFilesPathFromRootDir = getFilesPathFromRootDir;
exports.readFileContents = readFileContents;
exports.writeFileContents = writeFileContents;
var _fs = _interopRequireDefault(require("fs"));
var _path = _interopRequireDefault(require("path"));
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }
function checkIfFileExists(file) {
  try {
    _fs["default"].accessSync(file, _fs["default"].constants.F_OK);
    return true;
  } catch (err) {
    return false;
  }
}
function readFileContents(filePath) {
  try {
    var fileContents = _fs["default"].readFileSync(filePath, 'utf-8');
    return fileContents;
  } catch (err) {
    return null;
  }
}
function writeFileContents(filePath, content) {
  var writeOptions = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : {};
  var directoryPath = _path["default"].dirname(filePath);

  // Check if the directory exists
  if (!_fs["default"].existsSync(directoryPath)) {
    _fs["default"].mkdirSync(directoryPath, {
      recursive: true
    });
  }
  try {
    _fs["default"].writeFileSync("".concat(filePath), content, writeOptions);
  } catch (err) {
    throw new Error(err);
  }
}
function deleteFile(filePath) {
  if (checkIfFileExists(filePath)) {
    try {
      _fs["default"].unlinkSync(filePath);
    } catch (err) {
      throw new Error("Error while deleting the test data file: ".concat(filePath));
    }
  }
}
function deleteFolder(folderPath) {
  if (_fs["default"].existsSync(folderPath)) {
    try {
      _fs["default"].rmdirSync(folderPath, {
        recursive: true
      });
    } catch (err) {
      throw new Error("Error while deleting the test data file: ".concat(folderPath));
    }
  }
}
function getFilesPathFromRootDir(directoryPath) {
  var files = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : [];
  var absoluteDirPath = _path["default"].resolve(directoryPath);
  if (_fs["default"].statSync(absoluteDirPath).isFile()) {
    return [absoluteDirPath];
  }
  var fileList = _fs["default"].readdirSync(absoluteDirPath);
  fileList.forEach(function (file) {
    file = _path["default"].resolve(absoluteDirPath, file);
    if (_fs["default"].statSync(file).isDirectory()) {
      getFilesPathFromRootDir(file, files);
    }
    if (_fs["default"].statSync(file).isFile()) {
      files.push(file);
    }
  });
  return files;
}