"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.Logger = void 0;
var _fs = require("fs");
var _chalk = _interopRequireDefault(require("chalk"));
var _fileUtils = require("./fileUtils.js");
var _path = _interopRequireDefault(require("path"));
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }
function _typeof(o) { "@babel/helpers - typeof"; return _typeof = "function" == typeof Symbol && "symbol" == typeof Symbol.iterator ? function (o) { return typeof o; } : function (o) { return o && "function" == typeof Symbol && o.constructor === Symbol && o !== Symbol.prototype ? "symbol" : typeof o; }, _typeof(o); }
function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }
function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, _toPropertyKey(descriptor.key), descriptor); } }
function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); Object.defineProperty(Constructor, "prototype", { writable: false }); return Constructor; }
function _toPropertyKey(t) { var i = _toPrimitive(t, "string"); return "symbol" == _typeof(i) ? i : i + ""; }
function _toPrimitive(t, r) { if ("object" != _typeof(t) || !t) return t; var e = t[Symbol.toPrimitive]; if (void 0 !== e) { var i = e.call(t, r || "default"); if ("object" != _typeof(i)) return i; throw new TypeError("@@toPrimitive must return a primitive value."); } return ("string" === r ? String : Number)(t); }
var LoggerImpl = /*#__PURE__*/function () {
  function LoggerImpl() {
    _classCallCheck(this, LoggerImpl);
    this.loadingChars = ['⠋', '⠙', '⠹', '⠸', '⠼', '⠴', '⠦', '⠧', '⠇', '⠏'];
    this.currentIndex = 0;
    this.intervalId = null;
    this.SUCCESS_TYPE = "success";
    this.FAILURE_TYPE = "failure";
    this.INFO_TYPE = "info";
    this.PATH_TYPE = "path";
    this.logPath = _path["default"].resolve(process.cwd(), "lint-report", "sonar-logs.properties");
    this.colors = {
      success: ["\x1b[36m", "\x1b[0m"],
      failure: ["\x1b[31m", "\x1b[0m"],
      info: ["\x1b[33m", "\x1b[0m"]
    };
    this.cliColors = {
      success: _chalk["default"].green,
      failure: _chalk["default"].red,
      info: _chalk["default"].white,
      path: _chalk["default"].white.underline
    };
    this.consoleLogger = console;
  }
  return _createClass(LoggerImpl, [{
    key: "error",
    value: function error(err) {
      this.consoleLogger.error(err);
    }
  }, {
    key: "info",
    value: function info() {}
  }, {
    key: "log",
    value: function log(type, message) {
      var color = this.colors[type];
      this.consoleLogger.log("".concat(color[0]).concat(message).concat(color[1]));
    }
  }, {
    key: "createLogFile",
    value: function createLogFile() {
      (0, _fileUtils.writeFileContents)(this.logPath, "");
    }
  }, {
    key: "note",
    value: function note(content) {
      (0, _fs.appendFileSync)(this.logPath, content.toString());
    }
  }, {
    key: "cliLog",
    value: function cliLog(type, message) {
      var consolePrefix = type == "success" ? "\u2714" : type == "failure" ? "\u2718" : "";
      var color = this.cliColors[type];
      this.consoleLogger.log(color("".concat(consolePrefix, " ").concat(message)));
    }
  }, {
    key: "start",
    value: function start(message) {
      var _this = this;
      this.intervalId = setInterval(function () {
        process.stdout.write("\r".concat(_this.loadingChars[_this.currentIndex], " ").concat(message));
        _this.currentIndex = (_this.currentIndex + 1) % _this.loadingChars.length;
      }, 100);
    }
  }, {
    key: "stop",
    value: function stop() {
      clearInterval(this.intervalId);
      process.stdout.clearLine();
      process.stdout.cursorTo(0);
    }
  }]);
}();
var Logger = exports.Logger = new LoggerImpl();